#!/bin/bash 
set -e

source config
LOG=${LOG_DIR}/querygen.log
> $LOG # clear the log

start=$(($(date +%s%N)/1000000))
SEED=`date +%m%d%H%M%S%1N` 
log info "Seed is $SEED" | tee -a $LOG 2>&1

log info "Start to generate queries ..." | tee -a $LOG 2>&1

{
  # Copy from offical toolset, apply patches, build dsqgen
  mkdir -p ${BUILD_DIR}
  rm -fr ${BUILD_DIR}/${TOOLS_VERSION}; cp -r $bin/${TOOLS_VERSION} ${BUILD_DIR}

  # apply patches
  cat $bin/patches/query_templates/*.diff | patch -p1 -d ${BUILD_DIR}/${TOOLS_VERSION}/query_templates
  cat $bin/patches/dialect/*.diff | patch -p1 -d ${BUILD_DIR}/${TOOLS_VERSION}/query_templates

  log info "${BUILD_DIR}/${TOOLS_VERSION}" 
  cd ${BUILD_DIR}/${TOOLS_VERSION}/tools;make clean; make dsqgen 
  mkdir -p ${BUILD_DIR}/queries 

  log info `./dsqgen -release 2>&1`

  ./dsqgen -directory ../query_templates -input ../query_templates/templates.lst -scale ${SF} -streams 9 -output_dir ${BUILD_DIR}/queries -dialect sparksql -rngseed $SEED
  for i in `seq 0 8`; do sed -i "s/##STREAMNUM##/$i/" ${BUILD_DIR}/queries/query_$i.sql; done 
} >> $LOG 2>&1

log info "Prepare sqls for maintenance test." | tee -a $LOG 2>&1

for ii in `seq 1 4`; do
  date1_1=`head -n 1 ${BUILD_DIR}/delete/delete_$ii.dat | tail -n 1 | cut -f 1 -d '|'`
  date1_2=`head -n 1 ${BUILD_DIR}/delete/delete_$ii.dat | tail -n 1 | cut -f 2 -d '|'`
  sed -i "s/CSW_S_1/$date1_1/g" ${BUILD_DIR}/mtsqls_$ii/*.sql
  sed -i "s/CSW_E_1/$date1_2/g" ${BUILD_DIR}/mtsqls_$ii/*.sql

  date2_1=`head -n 2 ${BUILD_DIR}/delete/delete_$ii.dat | tail -n 1 | cut -f 1 -d '|'`
  date2_2=`head -n 2 ${BUILD_DIR}/delete/delete_$ii.dat | tail -n 1 | cut -f 2 -d '|'`
  sed -i "s/CSW_S_2/$date2_1/g" ${BUILD_DIR}/mtsqls_$ii/*.sql
  sed -i "s/CSW_E_2/$date2_2/g" ${BUILD_DIR}/mtsqls_$ii/*.sql

  date3_1=`head -n 3 ${BUILD_DIR}/delete/delete_$ii.dat | tail -n 1 | cut -f 1 -d '|'`
  date3_2=`head -n 3 ${BUILD_DIR}/delete/delete_$ii.dat | tail -n 1 | cut -f 2 -d '|'`
  sed -i "s/CSW_S_3/$date3_1/g" ${BUILD_DIR}/mtsqls_$ii/*.sql
  sed -i "s/CSW_E_3/$date3_2/g" ${BUILD_DIR}/mtsqls_$ii/*.sql

  date1_1=`head -n 1 ${BUILD_DIR}/inventory_delete/inventory_delete_$ii.dat | tail -n 1 | cut -f 1 -d '|'`
  date1_2=`head -n 1 ${BUILD_DIR}/inventory_delete/inventory_delete_$ii.dat | tail -n 1 | cut -f 2 -d '|'`
  sed -i "s/INV_S_1/$date1_1/g" ${BUILD_DIR}/mtsqls_$ii/*.sql
  sed -i "s/INV_E_1/$date1_2/g" ${BUILD_DIR}/mtsqls_$ii/*.sql

  date2_1=`head -n 2 ${BUILD_DIR}/inventory_delete/inventory_delete_$ii.dat | tail -n 1 | cut -f 1 -d '|'`
  date2_2=`head -n 2 ${BUILD_DIR}/inventory_delete/inventory_delete_$ii.dat | tail -n 1 | cut -f 2 -d '|'`
  sed -i "s/INV_S_2/$date2_1/g" ${BUILD_DIR}/mtsqls_$ii/*.sql
  sed -i "s/INV_E_2/$date2_2/g" ${BUILD_DIR}/mtsqls_$ii/*.sql

  date3_1=`head -n 3 ${BUILD_DIR}/inventory_delete/inventory_delete_$ii.dat | tail -n 1 | cut -f 1 -d '|'`
  date3_2=`head -n 3 ${BUILD_DIR}/inventory_delete/inventory_delete_$ii.dat | tail -n 1 | cut -f 2 -d '|'`
  sed -i "s/INV_S_3/$date3_1/g" ${BUILD_DIR}/mtsqls_$ii/*.sql
  sed -i "s/INV_E_3/$date3_2/g" ${BUILD_DIR}/mtsqls_$ii/*.sql
done

end=$(($(date +%s%N)/1000000))
duration=$(( (end - start) / 1000))
sec=`bc <<< "scale=3; ($end - $start)/1000"`
elapse_time=`printf "%d:%02d:%02d, %s seconds" $(($duration / 3600)) $((($duration / 60) % 60)) $(($duration % 60)) $sec`
log info "Generate queries finished. Time token: $elapse_time" | tee -a $LOG 2>&1

