set spark.scheduler.session.priority=true;

create database if not exists ${DB};
use ${DB};

-- ============================================================
--   Table: store
-- ============================================================
drop table if exists store;
create table store
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.store;

-- ============================================================
--   Table: call_center
-- ============================================================
drop table if exists call_center;
create table call_center
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.call_center;

-- ============================================================
--   Table: catalog_page
-- ============================================================
drop table if exists catalog_page;
create table catalog_page
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.catalog_page;

-- ============================================================
--   Table: web_site
-- ============================================================
drop table if exists web_site;
create table web_site
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.web_site;

-- ============================================================
--   Table: web_page
-- ============================================================
drop table if exists web_page;
create table web_page
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.web_page;

-- ============================================================
--   Table: warehouse
-- ============================================================
drop table if exists warehouse;
create table warehouse
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.warehouse;

-- ============================================================
--   Table: customer_address
-- ============================================================
drop table if exists customer_address;
create table customer_address
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.customer_address;

-- ============================================================
--   Table: customer_demographics
-- ============================================================
drop table if exists customer_demographics;
create table customer_demographics
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.customer_demographics;

-- ============================================================
--   Table: date_dim
-- ============================================================
drop table if exists date_dim;
create table date_dim
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.date_dim;

-- ============================================================
--   Table: household_demographics
-- ============================================================
drop table if exists household_demographics;
create table household_demographics
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.household_demographics;

-- ============================================================
--   Table: income_band
-- ============================================================
drop table if exists income_band;
create table income_band
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.income_band;

-- ============================================================
--   Table: promotion
-- ============================================================
drop table if exists promotion;
create table promotion
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.promotion;

-- ============================================================
--   Table: reason
-- ============================================================
drop table if exists reason;
create table reason
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.reason;

-- ============================================================
--   Table: ship_mode
-- ============================================================
drop table if exists ship_mode;
create table ship_mode
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.ship_mode;

-- ============================================================
--   Table: time_dim
-- ============================================================
drop table if exists time_dim;
create table time_dim
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true")
as select * from ${SOURCE}.time_dim;

-- ============================================================
--   Table: customer primary key exists, pre create table already
-- ============================================================
insert overwrite table customer
select
  tmp.c_customer_sk,
  tmp.c_customer_id,
  tmp.c_current_cdemo_sk,
  tmp.c_current_hdemo_sk,
  tmp.c_current_addr_sk,
  tmp.c_first_shipto_date_sk,
  tmp.c_first_sales_date_sk,
  tmp.c_salutation,
  tmp.c_first_name,
  tmp.c_last_name,
  tmp.c_preferred_cust_flag,
  tmp.c_birth_day,
  tmp.c_birth_month,
  tmp.c_birth_year,
  tmp.c_birth_country,
  tmp.c_login,
  tmp.c_email_address,
  tmp.c_last_review_date_sk
from(
  select
    c.c_customer_sk,
    c.c_customer_id,
    c.c_current_cdemo_sk,
    c.c_current_hdemo_sk,
    c.c_current_addr_sk,
    c.c_first_shipto_date_sk,
    c.c_first_sales_date_sk,
    c.c_salutation,
    c.c_first_name,
    c.c_last_name,
    c.c_preferred_cust_flag,
    c.c_birth_day,
    c.c_birth_month,
    c.c_birth_year,
    c.c_birth_country,
    c.c_login,
    c.c_email_address,
    c.c_last_review_date_sk
  from ${SOURCE}.customer c
) tmp
;

-- ============================================================
--   Table: item primary key exists, pre create table already
-- ============================================================
insert overwrite table item
select
  tmp.i_item_sk,
  tmp.i_item_id,
  tmp.i_rec_start_date,
  tmp.i_rec_end_date,
  tmp.i_item_desc,
  tmp.i_current_price,
  tmp.i_wholesale_cost,
  tmp.i_brand_id,
  tmp.i_brand,
  tmp.i_class_id,
  tmp.i_class,
  tmp.i_category_id,
  tmp.i_category,
  tmp.i_manufact_id,
  tmp.i_manufact,
  tmp.i_size,
  tmp.i_formulation,
  tmp.i_color,
  tmp.i_units,
  tmp.i_container,
  tmp.i_manager_id,
  tmp.i_product_name
from(
  select
    i.i_item_sk,
    i.i_item_id,
    i.i_rec_start_date,
    i.i_rec_end_date,
    i.i_item_desc,
    i.i_current_price,
    i.i_wholesale_cost,
    i.i_brand_id,
    i.i_brand,
    i.i_class_id,
    i.i_class,
    i.i_category_id,
    i.i_category,
    i.i_manufact_id,
    i.i_manufact,
    i.i_size,
    i.i_formulation,
    i.i_color,
    i.i_units,
    i.i_container,
    i.i_manager_id,
    i.i_product_name
  from ${SOURCE}.item i
) tmp
;

ANALYZE TABLE store COMPUTE STATISTICS;
ANALYZE TABLE store COMPUTE STATISTICS FOR COLUMNS s_store_sk, s_store_id, s_rec_start_date, s_rec_end_date, s_closed_date_sk, s_store_name, s_number_employees, s_floor_space, s_hours, s_manager, s_market_id, s_geography_class, s_market_desc, s_market_manager, s_division_id, s_division_name, s_company_id, s_company_name, s_street_number, s_street_name, s_street_type, s_suite_number, s_city, s_county, s_state, s_zip, s_country, s_gmt_offset, s_tax_precentage;
ANALYZE TABLE call_center COMPUTE STATISTICS;
ANALYZE TABLE call_center COMPUTE STATISTICS FOR COLUMNS cc_call_center_sk, cc_call_center_id, cc_rec_start_date, cc_rec_end_date, cc_closed_date_sk, cc_open_date_sk, cc_name, cc_class, cc_employees, cc_sq_ft, cc_hours, cc_manager, cc_mkt_id, cc_mkt_class, cc_mkt_desc, cc_market_manager, cc_division, cc_division_name, cc_company, cc_company_name, cc_street_number, cc_street_name, cc_street_type, cc_suite_number, cc_city, cc_county, cc_state, cc_zip, cc_country, cc_gmt_offset, cc_tax_percentage;
ANALYZE TABLE catalog_page COMPUTE STATISTICS;
ANALYZE TABLE catalog_page COMPUTE STATISTICS FOR COLUMNS cp_catalog_page_sk, cp_catalog_page_id, cp_start_date_sk, cp_end_date_sk, cp_department, cp_catalog_number, cp_catalog_page_number, cp_description, cp_type;
ANALYZE TABLE web_site COMPUTE STATISTICS;
ANALYZE TABLE web_site COMPUTE STATISTICS FOR COLUMNS web_site_sk, web_site_id, web_rec_start_date, web_rec_end_date, web_name, web_open_date_sk, web_close_date_sk, web_class, web_manager, web_mkt_id, web_mkt_class, web_mkt_desc, web_market_manager, web_company_id, web_company_name, web_street_number, web_street_name, web_street_type, web_suite_number, web_city, web_county, web_state, web_zip, web_country, web_gmt_offset, web_tax_percentage;
ANALYZE TABLE web_page COMPUTE STATISTICS;
ANALYZE TABLE web_page COMPUTE STATISTICS FOR COLUMNS wp_web_page_sk, wp_web_page_id, wp_rec_start_date, wp_rec_end_date, wp_creation_date_sk, wp_access_date_sk, wp_autogen_flag, wp_customer_sk, wp_url, wp_type, wp_char_count, wp_link_count, wp_image_count, wp_max_ad_count;
ANALYZE TABLE warehouse COMPUTE STATISTICS;
ANALYZE TABLE warehouse COMPUTE STATISTICS FOR COLUMNS w_warehouse_sk, w_warehouse_id, w_warehouse_name, w_warehouse_sq_ft, w_street_number, w_street_name, w_street_type, w_suite_number, w_city, w_county, w_state, w_zip, w_country, w_gmt_offset;
ANALYZE TABLE customer COMPUTE STATISTICS;
ANALYZE TABLE customer COMPUTE STATISTICS FOR COLUMNS c_customer_sk, c_customer_id, c_current_cdemo_sk, c_current_hdemo_sk, c_current_addr_sk, c_first_shipto_date_sk, c_first_sales_date_sk, c_salutation, c_first_name, c_last_name, c_preferred_cust_flag, c_birth_day, c_birth_month, c_birth_year, c_birth_country, c_login, c_email_address, c_last_review_date_sk;
ANALYZE TABLE customer_address COMPUTE STATISTICS;
ANALYZE TABLE customer_address COMPUTE STATISTICS FOR COLUMNS ca_address_sk, ca_address_id, ca_street_number, ca_street_name, ca_street_type, ca_suite_number, ca_city, ca_county, ca_state, ca_zip, ca_country, ca_gmt_offset, ca_location_type;
ANALYZE TABLE customer_demographics COMPUTE STATISTICS;
ANALYZE TABLE customer_demographics COMPUTE STATISTICS FOR COLUMNS cd_demo_sk, cd_gender, cd_marital_status, cd_education_status, cd_purchase_estimate, cd_credit_rating, cd_dep_count, cd_dep_employed_count, cd_dep_college_count;
ANALYZE TABLE date_dim COMPUTE STATISTICS;
ANALYZE TABLE date_dim COMPUTE STATISTICS FOR COLUMNS d_date_sk, d_date_id, d_date, d_month_seq, d_week_seq, d_quarter_seq, d_year, d_dow, d_moy, d_dom, d_qoy, d_fy_year, d_fy_quarter_seq, d_fy_week_seq, d_day_name, d_quarter_name, d_holiday, d_weekend, d_following_holiday, d_first_dom, d_last_dom, d_same_day_ly, d_same_day_lq, d_current_day, d_current_week, d_current_month, d_current_quarter, d_current_year;
ANALYZE TABLE household_demographics COMPUTE STATISTICS;
ANALYZE TABLE household_demographics COMPUTE STATISTICS FOR COLUMNS hd_demo_sk, hd_income_band_sk, hd_buy_potential, hd_dep_count, hd_vehicle_count;
ANALYZE TABLE item COMPUTE STATISTICS;
ANALYZE TABLE item COMPUTE STATISTICS FOR COLUMNS i_item_sk, i_item_id, i_rec_start_date, i_rec_end_date, i_item_desc, i_current_price, i_wholesale_cost, i_brand_id, i_brand, i_class_id, i_class, i_category_id, i_category, i_manufact_id, i_manufact, i_size, i_formulation, i_color, i_units, i_container, i_manager_id, i_product_name;
ANALYZE TABLE income_band COMPUTE STATISTICS;
ANALYZE TABLE income_band COMPUTE STATISTICS FOR COLUMNS ib_income_band_sk, ib_lower_bound, ib_upper_bound;
ANALYZE TABLE promotion COMPUTE STATISTICS;
ANALYZE TABLE promotion COMPUTE STATISTICS FOR COLUMNS p_promo_sk, p_promo_id, p_start_date_sk, p_end_date_sk, p_item_sk, p_cost, p_response_target, p_promo_name, p_channel_dmail, p_channel_email, p_channel_catalog, p_channel_tv, p_channel_radio, p_channel_press, p_channel_event, p_channel_demo, p_channel_details, p_purpose, p_discount_active;
ANALYZE TABLE reason COMPUTE STATISTICS;
ANALYZE TABLE reason COMPUTE STATISTICS FOR COLUMNS r_reason_sk, r_reason_id, r_reason_desc;
ANALYZE TABLE ship_mode COMPUTE STATISTICS;
ANALYZE TABLE ship_mode COMPUTE STATISTICS FOR COLUMNS sm_ship_mode_sk, sm_ship_mode_id, sm_type, sm_code, sm_carrier, sm_contract;
ANALYZE TABLE time_dim COMPUTE STATISTICS;
ANALYZE TABLE time_dim COMPUTE STATISTICS FOR COLUMNS t_time_sk, t_time_id, t_time, t_hour, t_minute, t_second, t_am_pm, t_shift, t_sub_shift, t_meal_time;
