set spark.scheduler.session.priority=true;

create database if not exists ${DB};
use ${DB};

-- ============================================================
--   Table: store_returns                                      
-- ============================================================
drop table if exists store_returns;
create table store_returns
(
    sr_returned_date_sk       bigint,
    sr_return_time_sk         bigint,
    sr_item_sk                bigint            not null,
    sr_customer_sk            bigint,
    sr_cdemo_sk               bigint,
    sr_hdemo_sk               bigint,
    sr_addr_sk                bigint,
    sr_store_sk               bigint,
    sr_reason_sk              bigint,
    sr_ticket_number          bigint            not null,
    sr_return_quantity        int,
    sr_return_amt             decimal(7,2),
    sr_return_tax             decimal(7,2),
    sr_return_amt_inc_tax     decimal(7,2),
    sr_fee                    decimal(7,2),
    sr_return_ship_cost       decimal(7,2),
    sr_refunded_cash          decimal(7,2),
    sr_reversed_charge        decimal(7,2),
    sr_store_credit           decimal(7,2),
    sr_net_loss               decimal(7,2)
)
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
partitioned by (sr_returned_date_sk)
TBLPROPERTIES("transactional"="true");

insert overwrite table store_returns partition (sr_returned_date_sk)
  select
    sr.sr_return_time_sk,
    sr.sr_item_sk,
    sr.sr_customer_sk,
    sr.sr_cdemo_sk,
    sr.sr_hdemo_sk,
    sr.sr_addr_sk,
    sr.sr_store_sk,
    sr.sr_reason_sk,
    sr.sr_ticket_number,
    sr.sr_return_quantity,
    sr.sr_return_amt,
    sr.sr_return_tax,
    sr.sr_return_amt_inc_tax,
    sr.sr_fee,
    sr.sr_return_ship_cost,
    sr.sr_refunded_cash,
    sr.sr_reversed_charge,
    sr.sr_store_credit,
    sr.sr_net_loss,
    sr.sr_returned_date_sk
  from ${SOURCE}.store_returns sr
  distribute by case when sr.sr_returned_date_sk is not null then sr.sr_returned_date_sk else sr.sr_ticket_number % 601 end
;

