set spark.scheduler.session.priority=true;

create database if not exists ${DB};
use ${DB};

-- ============================================================
--   Table: store_sales                                      
-- ============================================================
drop table if exists store_sales;
create table store_sales
(
    ss_sold_date_sk           bigint,
    ss_sold_time_sk           bigint,
    ss_item_sk                bigint            not null,
    ss_customer_sk            bigint,
    ss_cdemo_sk               bigint,
    ss_hdemo_sk               bigint,
    ss_addr_sk                bigint,
    ss_store_sk               bigint,
    ss_promo_sk               bigint,
    ss_ticket_number          bigint            not null,
    ss_quantity               int,
    ss_wholesale_cost         decimal(7,2),
    ss_list_price             decimal(7,2),
    ss_sales_price            decimal(7,2),
    ss_ext_discount_amt       decimal(7,2),
    ss_ext_sales_price        decimal(7,2),
    ss_ext_wholesale_cost     decimal(7,2),
    ss_ext_list_price         decimal(7,2),
    ss_ext_tax                decimal(7,2),
    ss_coupon_amt             decimal(7,2),
    ss_net_paid               decimal(7,2),
    ss_net_paid_inc_tax       decimal(7,2),
    ss_net_profit             decimal(7,2),
    constraint fk1 foreign key (ss_item_sk) references item(i_item_sk),
    constraint fk2 foreign key (ss_customer_sk) references customer(c_customer_sk)
)
using parquet OPTIONS(parquet.compression "SNAPPY", parquet.enable.dictionary "false", parquet.writer.version "v2")
partitioned by (ss_sold_date_sk)
TBLPROPERTIES("transactional"="true");

insert overwrite table store_sales partition (ss_sold_date_sk)
  select
    ss.ss_sold_time_sk,
    ss.ss_item_sk,
    ss.ss_customer_sk,
    ss.ss_cdemo_sk,
    ss.ss_hdemo_sk,
    ss.ss_addr_sk,
    ss.ss_store_sk,
    ss.ss_promo_sk,
    ss.ss_ticket_number,
    ss.ss_quantity,
    ss.ss_wholesale_cost,
    ss.ss_list_price,
    ss.ss_sales_price,
    ss.ss_ext_discount_amt,
    ss.ss_ext_sales_price,
    ss.ss_ext_wholesale_cost,
    ss.ss_ext_list_price,
    ss.ss_ext_tax,
    ss.ss_coupon_amt,
    ss.ss_net_paid,
    ss.ss_net_paid_inc_tax,
    ss.ss_net_profit,
    ss.ss_sold_date_sk
  from ${SOURCE}.store_sales ss
  distribute by case when ss.ss_sold_date_sk is not null then ss.ss_sold_date_sk else ss.ss_ticket_number % 601 end
;

