#!/bin/bash
set -e

source config

start=$(($(date +%s%N)/1000000))
log info "Refresh round $1 started."
log info "Executing update/delete methods ..."

ROUND=$1

# Delete Functions
beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${BUILD_DIR}/mtsqls_${ROUND}/DF_CS.sql --hivevar ROUND=${ROUND} > ${LOG_DIR}/DF_CS_$1.out 2> ${LOG_DIR}/DF_CS_$1.err &
beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${BUILD_DIR}/mtsqls_${ROUND}/DF_I.sql --hivevar ROUND=${ROUND} > ${LOG_DIR}/DF_I_$1.out 2> ${LOG_DIR}/DF_I_$1.err &
beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${BUILD_DIR}/mtsqls_${ROUND}/DF_SS.sql --hivevar ROUND=${ROUND} > ${LOG_DIR}/DF_SS_$1.out 2> ${LOG_DIR}/DF_SS_$1.err &
beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${BUILD_DIR}/mtsqls_${ROUND}/DF_WS.sql --hivevar ROUND=${ROUND} > ${LOG_DIR}/DF_WS_$1.out 2> ${LOG_DIR}/DF_WS_$1.err &

wait

# Update CS and CR
{
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${BUILD_DIR}/mtsqls_${ROUND}/LF_CR.sql --hivevar ROUND=${ROUND} > ${LOG_DIR}/LF_CR_$1.out 2> ${LOG_DIR}/LF_CR_$1.err
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${BUILD_DIR}/mtsqls_${ROUND}/LF_CS.sql --hivevar ROUND=${ROUND} > ${LOG_DIR}/LF_CS_$1.out 2> ${LOG_DIR}/LF_CS_$1.err
}&

# Update I
{
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${BUILD_DIR}/mtsqls_${ROUND}/LF_I.sql --hivevar ROUND=${ROUND} > ${LOG_DIR}/LF_I_$1.out 2> ${LOG_DIR}/LF_I_$1.err
}&

# Update SR and SS
{
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${BUILD_DIR}/mtsqls_${ROUND}/LF_SR.sql --hivevar ROUND=${ROUND} > ${LOG_DIR}/LF_SR_$1.out 2> ${LOG_DIR}/LF_SR_$1.err
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${BUILD_DIR}/mtsqls_${ROUND}/LF_SS.sql --hivevar ROUND=${ROUND} > ${LOG_DIR}/LF_SS_$1.out 2> ${LOG_DIR}/LF_SS_$1.err
}&

# Update WR and WS
{
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${BUILD_DIR}/mtsqls_${ROUND}/LF_WR.sql --hivevar ROUND=${ROUND} > ${LOG_DIR}/LF_WR_$1.out 2> ${LOG_DIR}/LF_WR_$1.err
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${BUILD_DIR}/mtsqls_${ROUND}/LF_WS.sql --hivevar ROUND=${ROUND} > ${LOG_DIR}/LF_WS_$1.out 2> ${LOG_DIR}/LF_WS_$1.err
}&

wait


end=$(($(date +%s%N)/1000000))
duration=$(( (end - start) / 1000))
sec=`bc <<< "scale=3; ($end - $start)/1000"`
elapse_time=`printf "%d:%02d:%02d, %s seconds" $(($duration / 3600)) $((($duration / 60) % 60)) $(($duration % 60)) $sec`
log info "Refresh round $1 finished. Time token: $elapse_time"

