#!/usr/bin/env bash

set -e

source ./config
CONFIG_LOG_DIR=${LOG_DIR}/emr_configs/

if [[ ! -d $CONFIG_LOG_DIR ]]; then
  mkdir -p $CONFIG_LOG_DIR
fi

start=$(($(date +%s%N)/1000000))
log info "Start to collect EMR configs ..."

function collect_config_of_node() {
  node_type=$1
  node_num=$2
  mkdir -p $CONFIG_LOG_DIR/${node_type}-${node_num}/hadoop-conf
  mkdir -p $CONFIG_LOG_DIR/${node_type}-${node_num}/spark-conf
  mkdir -p $CONFIG_LOG_DIR/${node_type}-${node_num}/hive-conf
  if [[ ${node_type} == "header" && ${node_num} == "1" ]]; then
    scp emr-${node_type}-${node_num}:/etc/my.cnf $CONFIG_LOG_DIR/${node_type}-${node_num}/ > /dev/null
  fi
  scp emr-${node_type}-${node_num}:/etc/ecm/hadoop-conf/* $CONFIG_LOG_DIR/${node_type}-${node_num}/hadoop-conf/ > /dev/null
  scp emr-${node_type}-${node_num}:/etc/ecm/spark-conf/* $CONFIG_LOG_DIR/${node_type}-${node_num}/spark-conf/ > /dev/null
  scp emr-${node_type}-${node_num}:/etc/ecm/hive-conf/* $CONFIG_LOG_DIR/${node_type}-${node_num}/hive-conf/ > /dev/null
}

collect_config_of_node header 1
log info "collect on node emr-header-1 done"

for i in `seq 1 $wn`; do
  collect_config_of_node worker $i
  log info "collect on node emr-worker-$i done"
done

cp collect_emr_configs.sh $CONFIG_LOG_DIR

end=$(($(date +%s%N)/1000000))
duration=$(( (end - start) / 1000))
sec=`bc <<< "scale=3; ($end - $start)/1000"`
elapse_time=`printf "%d:%02d:%02d, %s seconds" $(($duration / 3600)) $((($duration / 60) % 60)) $(($duration % 60)) $sec`
log info "Collect EMR configs finished. Time token: $elapse_time" | tee -a $LOG 2>&1
