#!/usr/bin/env bash

set -e

source ./config
CONFIG_LOG_DIR=${LOG_DIR}/system_profiles/

if [[ ! -d $CONFIG_LOG_DIR ]]; then
  mkdir -p $CONFIG_LOG_DIR
fi

start=$(($(date +%s%N)/1000000))
log info "Start to collect system HW profiles ..."

function collect_config_of_node() {
  node_type=$1
  node_num=$2
  mkdir -p $CONFIG_LOG_DIR/${node_type}-${node_num}/
  ssh emr-${node_type}-${node_num} "cat /proc/cpuinfo" > $CONFIG_LOG_DIR/${node_type}-${node_num}/cpu.out
  ssh emr-${node_type}-${node_num} "free -g" > $CONFIG_LOG_DIR/${node_type}-${node_num}/memory.out
  ssh emr-${node_type}-${node_num} "df" > $CONFIG_LOG_DIR/${node_type}-${node_num}/disk.out
  ssh emr-${node_type}-${node_num} "sudo ifconfig" > $CONFIG_LOG_DIR/${node_type}-${node_num}/network.out
  ssh emr-${node_type}-${node_num} "cat /etc/hosts" > $CONFIG_LOG_DIR/${node_type}-${node_num}/hosts.out
  ssh emr-${node_type}-${node_num} "cat /etc/security/limits.conf" > $CONFIG_LOG_DIR/${node_type}-${node_num}/limits.out
}

collect_config_of_node header 1
log info "collect on emr-header-1 done"

for i in `seq 1 $wn`; do
  collect_config_of_node worker $i
  log info "collect on emr-worker-$i done"
done

cp collect_system_profiles.sh $CONFIG_LOG_DIR

end=$(($(date +%s%N)/1000000))
duration=$(( (end - start) / 1000))
sec=`bc <<< "scale=3; ($end - $start)/1000"`
elapse_time=`printf "%d:%02d:%02d, %s seconds" $(($duration / 3600)) $((($duration / 60) % 60)) $(($duration % 60)) $sec`
log info "Collect system HW profiles finished. Time token: $elapse_time" | tee -a $LOG 2>&1
