#!/usr/bin/env bash
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Set Hadoop-specific environment variables here.

# The only required environment variable is JAVA_HOME.  All others are
# optional.  When running a distributed configuration it is best to
# set JAVA_HOME in this file, so that it is correctly defined on
# remote nodes.

# The java implementation to use.
export JAVA_HOME=${JAVA_HOME}

# The jsvc implementation to use. Jsvc is required to run secure datanodes
# that bind to privileged ports to provide authentication of data transfer
# protocol.  Jsvc is not required if SASL is configured for authentication of
# data transfer protocol using non-privileged ports.
#export JSVC_HOME=${JSVC_HOME}

export HADOOP_CONF_DIR=${HADOOP_CONF_DIR:-"/etc/hadoop"}

# Extra Java CLASSPATH elements.  Automatically insert capacity-scheduler.
for f in $HADOOP_HOME/contrib/capacity-scheduler/*.jar; do
  if [ "$HADOOP_CLASSPATH" ]; then
    export HADOOP_CLASSPATH=$HADOOP_CLASSPATH:$f
  else
    export HADOOP_CLASSPATH=$f
  fi
done

# The maximum amount of heap to use, in MB. Default is 1000.
#export HADOOP_HEAPSIZE=
#export HADOOP_NAMENODE_INIT_HEAPSIZE=""

# Extra Java runtime options.  Empty by default.
#export HADOOP_OPTS="$HADOOP_OPTS -Djava.net.preferIPv4Stack=true"

# Command specific options appended to HADOOP_OPTS when specified

SHARED_HADOOP_NAMENODE_OPTS="-XX:ErrorFile=$HADOOP_LOG_DIR/hs_err_pid%p.log -Dhadoop.security.logger=${HADOOP_SECURITY_LOGGER:-INFO,RFAS}"

NAMENODE_JAVAAGEGENT_OPTS="-javaagent:/var/lib/ecm-agent/data/jmxetric-1.0.8.jar=host=localhost,port=8649,mode=unicast,wireformat31x=true,process=HDFS_NameNode,config=/var/lib/ecm-agent/data/jmxetric.xml"
SECONDARYNAMENODE_JAVAAGEGENT_OPTS="-javaagent:/var/lib/ecm-agent/data/jmxetric-1.0.8.jar=host=localhost,port=8649,mode=unicast,wireformat31x=true,process=HDFS_SecondaryNameNode,config=/var/lib/ecm-agent/data/jmxetric.xml"
DATANODE_JAVAAGEGENT_OPTS="-javaagent:/var/lib/ecm-agent/data/jmxetric-1.0.8.jar=host=localhost,port=8649,mode=unicast,wireformat31x=true,process=HDFS_DataNode,config=/var/lib/ecm-agent/data/jmxetric.xml"

export HADOOP_NAMENODE_OPTS=" -server -XX:ParallelGCThreads=8 -XX:+UseConcMarkSweepGC -XX:NewRatio=3 -verbose:gc -XX:+PrintGCDetails -XX:+PrintGCTimeStamps -XX:+PrintGCDateStamps -XX:+UseGCLogFileRotation -XX:NumberOfGCLogFiles=5 -XX:GCLogFileSize=100M -XX:CMSInitiatingOccupancyFraction=80 -XX:+UseCMSInitiatingOccupancyOnly -XX:+DisableExplicitGC $SHARED_HADOOP_NAMENODE_OPTS -Xloggc:$HADOOP_LOG_DIR/namenode-gc.log -Dhdfs.audit.logger=INFO,RFAAUDIT $NAMENODE_JAVAAGEGENT_OPTS"
export HADOOP_DATANODE_OPTS="-Dhadoop.security.logger=ERROR,RFAS $HADOOP_DATANODE_OPTS $DATANODE_JAVAAGEGENT_OPTS"
export HADOOP_SECONDARYNAMENODE_OPTS="-server -XX:ParallelGCThreads=8 -XX:+UseConcMarkSweepGC -XX:NewRatio=3 -verbose:gc -XX:+PrintGCDetails -XX:+PrintGCTimeStamps -XX:+PrintGCDateStamps -XX:+UseGCLogFileRotation -XX:NumberOfGCLogFiles=5 -XX:GCLogFileSize=100M -XX:CMSInitiatingOccupancyFraction=80 -XX:+UseCMSInitiatingOccupancyOnly -XX:+DisableExplicitGC $SHARED_HADOOP_NAMENODE_OPTS  -Xloggc:$HADOOP_LOG_DIR/secondary-gc.log -Dhdfs.audit.logger=${HDFS_AUDIT_LOGGER:-INFO,NullAppender} $SECONDARYNAMENODE_JAVAAGEGENT_OPTS"

export HADOOP_NFS3_OPTS="$HADOOP_NFS3_OPTS"
export HADOOP_PORTMAP_OPTS="-Xmx512m $HADOOP_PORTMAP_OPTS"

ZKFC_JAVAAGEGENT_OPTS="-javaagent:/var/lib/ecm-agent/data/jmxetric-1.0.8.jar=host=localhost,port=8649,mode=unicast,wireformat31x=true,process=HDFS_ZKFC,config=/var/lib/ecm-agent/data/jmxetric.xml"
export HADOOP_ZKFC_OPTS="$HADOOP_ZKFC_OPTS $ZKFC_JAVAAGEGENT_OPTS"
JOURNALNODE_JAVAAGEGENT_OPTS="-javaagent:/var/lib/ecm-agent/data/jmxetric-1.0.8.jar=host=localhost,port=8649,mode=unicast,wireformat31x=true,process=HDFS_JournalNode,config=/var/lib/ecm-agent/data/jmxetric.xml"
export HADOOP_JOURNALNODE_OPTS="$HADOOP_JOURNALNODE_OPTS $JOURNALNODE_JAVAAGEGENT_OPTS"


# The following applies to multiple commands (fs, dfs, fsck, distcp etc)
export HADOOP_CLIENT_OPTS="$HADOOP_CLIENT_OPTS"
# set heap args when HADOOP_HEAPSIZE is empty
if [ "$HADOOP_HEAPSIZE" = "" ]; then
  export HADOOP_CLIENT_OPTS="-Xmx512m $HADOOP_CLIENT_OPTS"
fi

#HADOOP_JAVA_PLATFORM_OPTS="-XX:-UsePerfData $HADOOP_JAVA_PLATFORM_OPTS"

# On secure datanodes, user to run the datanode as after dropping privileges.
# This **MUST** be uncommented to enable secure HDFS if using privileged ports
# to provide authentication of data transfer protocol.  This **MUST NOT** be
# defined if SASL is configured for authentication of data transfer protocol
# using non-privileged ports.
export HADOOP_SECURE_DN_USER=${HADOOP_SECURE_DN_USER}

# Where log files are stored.  $HADOOP_HOME/logs by default.
#export HADOOP_LOG_DIR=${HADOOP_LOG_DIR}/$USER

# Where log files are stored in the secure data environment.
export HADOOP_SECURE_DN_LOG_DIR=${HADOOP_LOG_DIR}/${HADOOP_HDFS_USER}

###
# HDFS Mover specific parameters
###
# Specify the JVM options to be used when starting the HDFS Mover.
# These options will be appended to the options specified as HADOOP_OPTS
# and therefore may override any similar flags set in HADOOP_OPTS
#
# export HADOOP_MOVER_OPTS=""

###
# Advanced Users Only!
###

# The directory where pid files are stored. /tmp by default.
# NOTE: this should be set to a directory that can only be written to by 
#       the user that will run the hadoop daemons.  Otherwise there is the
#       potential for a symlink attack.
export HADOOP_PID_DIR=${HADOOP_PID_DIR}
export HADOOP_SECURE_DN_PID_DIR=${HADOOP_PID_DIR}

# A string representing this instance of hadoop. $USER by default.
export HADOOP_IDENT_STRING=$USER

export HADOOP_NAMENODE_HEAPSIZE=5632
export HADOOP_DATANODE_HEAPSIZE=2816
export HADOOP_SECONDARY_NAMENODE_HEAPSIZE=1024



if [ "$HADOOP_HEAPSIZE" == "HADOOP_NAMENODE_HEAPSIZE" ]; then
  export HADOOP_HEAPSIZE=$HADOOP_NAMENODE_HEAPSIZE
  export HADOOP_NAMENODE_OPTS=$HADOOP_NAMENODE_OPTS" -Xms5632m "
fi

if [ "$HADOOP_HEAPSIZE" == "HADOOP_DATANODE_HEAPSIZE" ]; then
  export HADOOP_HEAPSIZE=$HADOOP_DATANODE_HEAPSIZE
fi

if [ "$HADOOP_HEAPSIZE" == "HADOOP_SECONDARY_NAMENODE_HEAPSIZE" ]; then
  export HADOOP_HEAPSIZE=$HADOOP_SECONDARY_NAMENODE_HEAPSIZE
fi